<?php

namespace Drupal\ebt_quote\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\ebt_core\Plugin\Field\FieldWidget\EbtSettingsDefaultWidget;

/**
 * Plugin implementation of the 'ebt_settings_quote' widget.
 *
 * @FieldWidget(
 *   id = "ebt_settings_quote",
 *   label = @Translation("EBT Quote settings"),
 *   field_types = {
 *     "ebt_settings"
 *   }
 * )
 */
class EbtSettingsQuoteWidget extends EbtSettingsDefaultWidget {

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    $element = parent::formElement($items, $delta, $element, $form, $form_state);

    $element['ebt_settings']['styles'] = [
      '#title' => $this->t('Styles'),
      '#type' => 'radios',
      '#options' => [
        'persona' => $this->t('Persona'),
        'company' => $this->t('Company'),
        'persona_with_small_icon' => $this->t('Persona with small icon'),
        'with_square_image' => $this->t('Width square image'),
        'with_frame_and_background_image' => $this->t('With frame and background image'),
      ],
      '#default_value' => $items[$delta]->ebt_settings['styles'] ?? 'persona',
      '#description' => $this->t('Select predefined styles for quote.'),
    ];

    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public function massageFormValues(array $values, array $form, FormStateInterface $form_state) {
    foreach ($values as &$value) {
      $value += ['ebt_settings' => []];
    }
    return $values;
  }

}
